Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(112)

Unified Diff: components/subresource_filter/content/browser/subresource_filter_client.h

Issue 2795053002: [subresource_filter] Implement the "Smart" UI on Android (Closed)
Patch Set: minor tweaks Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/subresource_filter/content/browser/subresource_filter_client.h
diff --git a/components/subresource_filter/content/browser/subresource_filter_client.h b/components/subresource_filter/content/browser/subresource_filter_client.h
index eb61f072ae1be11d63a14d2d96bdedbe95243b3e..6792ad691eb6f779a45d17804b28a41406f50d80 100644
--- a/components/subresource_filter/content/browser/subresource_filter_client.h
+++ b/components/subresource_filter/content/browser/subresource_filter_client.h
@@ -34,9 +34,9 @@ class SubresourceFilterClient {
virtual bool ShouldSuppressActivation(
content::NavigationHandle* navigation_handle) = 0;
- // Adds |url| to the BLOCKED state via content settings for the current
- // profile.
- virtual void WhitelistByContentSettings(const GURL& url) = 0;
+ // Adds |top_level_url| to the BLOCKED state via content settings for the
+ // current profile.
+ virtual void WhitelistByContentSettings(const GURL& top_level_url) = 0;
// Adds |url| to a per-WebContents whitelist.
virtual void WhitelistInCurrentWebContents(const GURL& url) = 0;
« no previous file with comments | « components/content_settings/core/common/content_settings_types.h ('k') | tools/metrics/histograms/enums.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698